using JLD;

include("call_ssa.jl");
include("tukeywin.jl");
include("wiggle_plot.jl");

input  = load("SdS_synthetic_PREM.jld");
data   = input["SdS_PREM_data"];
dnoisy = input["SdS_PREM_dnoisy"];
offset = input["offset"];
time   = input["time"][:];
dt     = time[2] - time[1];           # sampling interval (s).

# apply cosine taper:
tp     = tukeywin(size(data, 1), 0.25);  # cosine windows.
data   = data .* repmat(tp[:], 1, size(data, 2));
dnoisy = dnoisy .* repmat(tp[:], 1, size(data, 2));  
    
XLABEL = "Distance (deg)";
YLABEL = "time to SS (s)";
s      = 15.0;        # scaling parameter.

TITLE  = "Input data";
wgbdata = wiggle_plot(data, time, offset, s, XLABEL, YLABEL, TITLE, 0.65);

TITLE     = "Noise added data";
wgbdnoisy = wiggle_plot(dnoisy, time, offset, s, XLABEL, YLABEL, TITLE, 0.65);

# SSA parameters:
flow  = 0.01;
fhigh = 0.06;
nitr  = 10;
alpha = 0.4;
k     = int(1: 6); 

# call SSA:

Q = zeros(size(k));
for ii = 1: length(k)
    dout = call_ssa(dnoisy, dt, k[ii], flow, fhigh, alpha, nitr);
    # Output:
    TITLE = @sprintf("Reconstructed data (using k = %d)", k[ii]);
    wgbdout = wiggle_plot(dout, time, offset, s, XLABEL, YLABEL, TITLE, 0.65); 

    TITLE = @sprintf("Difference between input and reconstructed data (using k = %d)", k[ii]);
    wgbdiff = wiggle_plot(data-dout, time, offset, s, XLABEL, YLABEL, TITLE, 0.65);

    Q[ii] = 10.0 * log10(norm(data[:], 2) / norm(data[:] - dout[:], 2));
end;

figure();
plot(k, Q, "k-o")
xlabel("k (rank)")
ylabel("Quality of the reconstruction")




