#
# 
# Inputs:    -din    input data matrix.
#            -dt     sampling interval (s).
#            -p      number of singular values used to
#                    reconstruct the data.
#            -flow   min freq. in the data (Hz).
#            -fhigh  max freq. in the data (Hz).
#            -alpha  hyper parameter (0-1).
#            -nitr   number of iterations.
#
# Output:
#            -dout   reconstructed data.
#  
include("fx_ssa.jl");

function call_ssa(din, dt, p, flow, fhigh, alpha, nitr)

 # Compute the Sampling Operaor (S):
 nx = size(din, 2);
 ny = size(din, 1);
 T  = Array(Float64, ny, nx);
 T  = ones(ny, nx);

 for ix = 1: nx
     a = sum(din[:, ix]);
     if (a == 0.0)
         T[:, ix] = 0.0;
     end; 
 end;

 aux  = zeros(size(din));
 aux  = din;

 for k = 1: nitr
     out  = fx_ssa(aux, dt, p, flow, fhigh);
     dout = alpha * din + (1 - alpha*T) .* out;
     aux  = dout;
 end
 
 # Output:
 return aux;
end
