#
# FX_SSA: Singular Spectrum Analysis is the fx domain for snr enhancement.
# 
# Inputs:   d         data (traces are columns)
#           dt        sampling interval (s)
#           p         number of singular values used to reconstuct the data
#           flow      min freq. in the data (Hz)
#           fhigh     max freq. in the data (Hz).
#
# Output:   DATA_f   filtered data.
#
include("ssa.jl");

function fx_ssa(DATA, dt, p, flow, fhigh)

 (nt, ntraces) = size(DATA);
 nf = 2 * nextpow2(nt);

 DATA_FX_f = zeros(nf, ntraces);
 
 # First and last samples of the DFT:
 df   = 1.0 / (dt[1]*nf[1]);
 fnyq = 1.0 / (2.0*dt[1]);
 ilow = floor(flow * dt * nf) + 1;
 ilow = int(ilow[1]);

 if (ilow < 1)
     ilow = 1;
 end

 ihigh = floor(fhigh * dt * nf) + 1;
 ihigh = int(ihigh[1]);

 if (ihigh > int(floor(nf/2))+1)
     ihigh = int(floor(nf/2)) + 1;
 end

 # Zeropad the input data:
 DATA_ = zeros(nf, ntraces); 
 if (nt == nf)
     DATA_ = DATA;
 elseif (nt < nf)
     DATA_[1: nt, :] = DATA;  
 end;

 # Transform to FX:
 DATA_FX   = fft(DATA_, 1);
 DATA_FX_f = zeros(size(DATA_FX)) + im * zeros(size(DATA_FX));

 nw = int(floor(ntraces/2));
 
 for k = ilow: ihigh
     tmp = DATA_FX[k, :];
     tmp = tmp[:];

     for j = 1: 10
         (tmp_out, Sing) = ssa(tmp, nw, p);
         tmp = tmp_out;
     end;
     DATA_FX_f[k, :] = tmp;
 end;
 
 # Honor Symmetries:
 for k = int(nf/2)+2: nf
     DATA_FX_f[k, :] = conj(DATA_FX_f[nf-k+2, :]);
 end;
 
 # Back to TX (the output):
 DATA_f = real(ifft(DATA_FX_f, 1));
 DATA_f = DATA_f[1: nt, :];

 return DATA_f;
end

