#
# This function returns an N-point Tukey window (known as cosine-tapered window).
#
# function tukeywin(N, R)
#
# Inputs:
# -N            length of the output window.
# -R            the ration of the length of taper section to the total length of
#               the window (0.0 < R <1.0).
# Outputs:
# -w            an N-point Tukey window (cosine-tapered window).
#
#

function tukeywin(N, R)
 N = int(N);
 R = float(R);

 if (R > 1)
     error("R has to be between 0.0 and 1.0.");
 end

 m = int(round(R * N / 2.0));

 # initializing the window:
 w = ones(N, 1);

 x = float([0: m-1]) / float(N-1);
 w[1: m, 1] = 0.5 * (1.0 + cos(2.0*pi/R * (x - R/2.0)));

 x = float([N-m: N-1]) / float(N-1);
 w[N-m+1: N, 1] = 0.5 * (1.0 + cos(2.0*pi/R * (x - 1.0 + R/2.0)));

 # output:
 return w
end

