#
# plot a seismic section using wiggles.
# 
# wiggle_plot(data, time, offset, s, XLABEL, YLABEL, TITLE);
# 
# Inputs:
#     data     seismic data (traces are columns).
#     time     time vector.
#     offset   offset vector.
#     s        scaling factor; data will be multiplied by s.
#     XLABEL   x-axis label.
#     YLABEL   y-axis label.
#     TITLE    figure title.
#     AR       figure aspect ration (height divided by width).
#

using Winston;

function wiggle_plot(data, time, offset, s, XLABEL, YLABEL, TITLE, AR)

data = data * s;

figure();
wgb = FramedPlot(title=TITLE);

for id = 1: size(data, 2)
    d  = data[:, id] + offset[id];
    d1 = data[:, id];
    ineg     = find(v -> (v < 0.0), d1);
    d1[ineg] = 0.0;
    d1 = d1 + offset[id];
    d2 = ones(size(d)) * offset[id];

    if (sum(data[:, id]) != 0.0) 
        add(wgb, FillBetween(d1, time, d2, time, color=0x9b9b9b))
        add(wgb, Curve(d, time, color=0x0b0b0b))   
    end;
end    
setattr(wgb.y1, "label", YLABEL);
setattr(wgb.x1, "label", XLABEL);
setattr(wgb, "yrange", (minimum(time), maximum(time)));
dx1 = abs(offset[2] - offset[1]);
dx2 = abs(offset[end] - offset[end-1]);
setattr(wgb, "xrange", (minimum(offset)-2*dx1, maximum(offset)+2*dx2));
setattr(wgb, "aspect_ratio", AR);
display(wgb)

return wgb;

end
